<?php
/*---------------------------------------------------------------*/
/* File Created by SMF Arcade 2.7.0.1
/* File Generated: Mon, 29 Jul 2024 00:54:32 GMT
/*---------------------------------------------------------------*/
$config = array(
	'active'	=> '1',
	'bgcolor'	=> '0',
	'gcat'		=> '3',
	'gkeyimg'	=> '0',
	'js_insertion'	=> '0',
	'gheight'	=> '480',
	'gwidth'	=> '800',
	'gkeys'		=> '',
	'gname'		=> 'PyramidSolitaire_Origon',
	'gtitle'	=> 'Pyramid Solitaire',
	'gwords'	=> 'Pair up all the cards in the deck that total up to 13. The valid pairs are Queen-Ace, Jack-2, 10-3, 9-4, 8-5 and 7-6.  Kings are discarded singly.',
	'object'	=> 'Pair up all the cards in the deck that total up to 13. The valid pairs are Queen-Ace, Jack-2, 10-3, 9-4, 8-5 and 7-6.  Kings are discarded singly.',
	'snggame'	=> '0',
	'gtype'		=> 'normal',
	'savetype'	=> 'html52',
	'html5'		=> '1',
);
?>